Module buffer

Support for Python buffer protocol

Structs

PyArrowBuffer
A wrapper around an Arrow Buffer.
PyBufferWrapper
A wrapper around a PyBuffer that applies a custom destructor that checks if the Python interpreter is still initialized before freeing the buffer memory.

Enums

AnyBufferProtocol
An enum over buffer protocol input types.