pub struct PyArray { /* private fields */ }Expand description
A Python-facing Arrow array.
This is a wrapper around an ArrayRef and a FieldRef.
It’s important for this to wrap both an array and a field so that it can faithfully store all
data transmitted via the __arrow_c_array__ Python method, which exports both an Array and a
Field.
In particular, storing a FieldRef is required to persist Arrow extension metadata through the
C Data Interface.
Implementations
Sourceimpl PyArray
impl PyArray
Sourcepub fn from_array_ref(array: ArrayRef) -> Self
pub fn from_array_ref(array: ArrayRef) -> Self
Create a new PyArray from an ArrayRef, inferring its data type automatically.
Sourcepub fn from_arrow_pycapsule(
schema_capsule: &Bound<'_, PyCapsule>,
array_capsule: &Bound<'_, PyCapsule>,
) -> PyResult<Self>
pub fn from_arrow_pycapsule( schema_capsule: &Bound<'_, PyCapsule>, array_capsule: &Bound<'_, PyCapsule>, ) -> PyResult<Self>
Import from raw Arrow capsules
Sourcepub fn into_inner(self) -> (ArrayRef, FieldRef)
pub fn into_inner(self) -> (ArrayRef, FieldRef)
Sourcepub fn to_arro3<'py>(&'py self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>
pub fn to_arro3<'py>(&'py self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>
Export to an arro3.core.Array.
This requires that you depend on arro3-core from your Python package.
Sourcepub fn into_arro3(self, py: Python<'_>) -> PyResult<Bound<'_, PyAny>>
pub fn into_arro3(self, py: Python<'_>) -> PyResult<Bound<'_, PyAny>>
Export to an arro3.core.Array.
This requires that you depend on arro3-core from your Python package.