Support for Python buffer protocol
Structs
- PyArrow
Buffer - A wrapper around an Arrow Buffer.
- PyBuffer
Wrapper - A wrapper around a PyBuffer that applies a custom destructor that checks if the Python interpreter is still initialized before freeing the buffer memory.
Enums
- AnyBuffer
Protocol - An enum over buffer protocol input types.