pub struct PyArrowBuffer(/* private fields */);Expand description
A wrapper around an Arrow Buffer.
This implements both import and export via the Python buffer protocol.
Buffer import
This can be very useful as a general way to support ingest of a Python buffer protocol object. The underlying Arrow Buffer manages the external memory, automatically calling the Python buffer’s release callback when the Arrow Buffer reference count reaches 0.
This does not need to be used with Arrow at all! This can be used with any API where you want
to handle both Python-provided and Rust-provided buffers. PyArrowBuffer implements
AsRef<[u8]>.
Buffer export
The Python buffer protocol is implemented on this buffer to enable zero-copy data transfer of
the core buffer into Python. This allows for zero-copy data sharing with numpy via
numpy.frombuffer.
Implementations
Sourceimpl PyArrowBuffer
impl PyArrowBuffer
Sourcepub fn new(buffer: Buffer) -> Self
pub fn new(buffer: Buffer) -> Self
Construct a new PyArrowBuffer
Sourcepub fn into_inner(self) -> Buffer
pub fn into_inner(self) -> Buffer
Consume and return the Buffer